function [GroupTrack, flag_new] = FindNewClusteringWithoutMinimizingJ(Group, GroupTrack, GroupCNL, F0Group, AllMustLink, CurrMustLink)
% Find a new clustering that satisfies current constraints, by exchanging
% group track labels in a swap set (of a notelet) of two tracks. The
% notelet was selected randomly first, and then enumerated sequentially
% untill a new clustering is found.
% Input
%   - Group         : Groups
%   - GroupTrack    : Track labels of groups
%   - GroupCNL      : Group cannot link lists
%   - F0Feature     : F0 features
%   - para          : Some parameters
% Output
%   - GroupTrack    : Updated track labels of groups
%   - flag_new      : flag to indicate if the clustering returned is new or not
%
% Author: Zhiyao Duan
% Created: 6/3/2009
% Last modified: 6/3/2009

groupNum = length(Group);
maxTrack = max(GroupTrack);

initg = ceil(rand * groupNum);                                          % randomize the initial notelet

for i = 1:groupNum
    % the current notelet
    currg = initg-1 + i;
    if currg > groupNum
        currg = mod(currg, groupNum);
    end    
    curr_track = GroupTrack(currg);
    
    tmp_Total_J = zeros(1, maxTrack);
    for target_track = 1:maxTrack
        if curr_track ~= target_track                                   % itself, do nothing
            % find the swap set of the current notelet, between the current track and the target track
            region = currg;
            region = FindExchangeRegion(currg, curr_track, target_track, GroupCNL, GroupTrack, region);
            curr_groups = region(GroupTrack(region)==curr_track);
            target_groups = region(GroupTrack(region)==target_track);
            
            % calculate Delta_distance of this exchange
            tmpGroupTrack = GroupTrack;
            tmpGroupTrack(curr_groups) = target_track;
            tmpGroupTrack(target_groups) = curr_track;
            
            % calculate the negative number of newly satisfied must-links
            tmp_Total_J(target_track) = -CountNewlySatisfiedMustLinks(region, tmpGroupTrack, F0Group, AllMustLink, CurrMustLink);
        end
    end
    
    [min_tmp_Total_J, target_track] = min(tmp_Total_J);                 % choose the best exchange
    
    % exchange if a new and better clustering is found
    if min_tmp_Total_J < 0
        region = currg;
        region = FindExchangeRegion(currg, curr_track, target_track, GroupCNL, GroupTrack, region);
        curr_groups = region(GroupTrack(region)==curr_track);
        target_groups = region(GroupTrack(region)==target_track);
        
        % update membership
        GroupTrack(curr_groups) = target_track;
        GroupTrack(target_groups) = curr_track;
        
        % done an exchange, then exit
        flag_new = 1;
        fprintf('\n');
        return;
    end    
    % no exchange is done, then continue the iteration
end
flag_new = 0;                                                           % did not find a new bettern clustering, the algorithm terminates
fprintf('\n');